==> smooth-scroll-into-view-if-needed-1.1.5.tgz: package/umd/smooth-scroll-into-view-if-needed.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.scrollIntoView = factory());
}(this, (function () { 'use strict';

  var viewport;
  var getViewport = (function () {
    if (!viewport) {
      viewport = document.compatMode === 'CSS1Compat' ? document.documentElement : document.scrollingElement || document.documentElement;
    }

    return viewport;
  });

  var isElement = function isElement(el) {
    return el != null && typeof el === 'object' && (el.nodeType === 1 || el.nodeType === 11);
  };

  var hasScrollableSpace = function hasScrollableSpace(el, axis) {
    return axis === 'X' ? el.clientWidth < el.scrollWidth : el.clientHeight < el.scrollHeight;
  };

  var canOverflow = function canOverflow(el, axis, skipOverflowHiddenElements) {
    var overflowValue = getComputedStyle(el, null)['overflow' + axis];

    if (skipOverflowHiddenElements && overflowValue === 'hidden') {
      return false;
    }

    return overflowValue !== 'visible' && overflowValue !== 'clip';
  };

  var isScrollable = function isScrollable(el, skipOverflowHiddenElements) {
    return el === getViewport() || hasScrollableSpace(el, 'Y') && canOverflow(el, 'Y', skipOverflowHiddenElements) || hasScrollableSpace(el, 'X') && canOverflow(el, 'X', skipOverflowHiddenElements);
  };

  var alignNearest = function alignNearest(scrollingEdgeStart, scrollingEdgeEnd, scrollingSize, scrollingBorderStart, scrollingBorderEnd, elementEdgeStart, elementEdgeEnd, elementSize) {
    if (elementEdgeStart < scrollingEdgeStart && elementEdgeEnd > scrollingEdgeEnd || elementEdgeStart > scrollingEdgeStart && elementEdgeEnd < scrollingEdgeEnd) {
      return 0;
    }

    if (elementEdgeStart < scrollingEdgeStart && elementSize < scrollingSize || elementEdgeEnd > scrollingEdgeEnd && elementSize > scrollingSize) {
      return elementEdgeStart - scrollingEdgeStart - scrollingBorderStart;
    }

    if (elementEdgeEnd > scrollingEdgeEnd && elementSize < scrollingSize || elementEdgeStart < scrollingEdgeStart && elementSize > scrollingSize) {
      return elementEdgeEnd - scrollingEdgeEnd + scrollingBorderEnd;
    }

    return 0;
  };

  var compute = (function (target, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        _options$scrollMode = _options.scrollMode,
        scrollMode = _options$scrollMode === void 0 ? 'always' : _options$scrollMode,
        _options$block = _options.block,
        block = _options$block === void 0 ? 'center' : _options$block,
        _options$inline = _options.inline,
        inline = _options$inline === void 0 ? 'nearest' : _options$inline,
        boundary = _options.boundary,
        _options$skipOverflow = _options.skipOverflowHiddenElements,
        skipOverflowHiddenElements = _options$skipOverflow === void 0 ? false : _options$skipOverflow;
    var checkBoundary = typeof boundary === 'function' ? boundary : function (node) {
      return node !== boundary;
    };

    if (!isElement(target)) {
      throw new Error('Element is required in scrollIntoView');
    }

    var targetRect = target.getBoundingClientRect();
    var frames = [];
    var parent;

    while (isElement(parent = target.parentNode || target.host) && checkBoundary(target)) {
      if (isScrollable(parent, skipOverflowHiddenElements)) {
        frames.push(parent);
      }

      target = parent;
    }

    var viewport = getViewport();
    var viewportWidth = window.visualViewport ? window.visualViewport.width : Math.min(viewport.clientWidth, window.innerWidth);
    var viewportHeight = window.visualViewport ? window.visualViewport.height : Math.min(viewport.clientHeight, window.innerHeight);
    var viewportX = window.scrollX || window.pageXOffset;
    var viewportY = window.scrollY || window.pageYOffset;

    if (scrollMode === 'if-needed') {
      var isVisible = frames.every(function (frame) {
        var frameRect = frame.getBoundingClientRect();

        if (targetRect.top < frameRect.top) {
          return false;
        }

        if (targetRect.bottom > frameRect.bottom) {
          return false;
        }

        if (frame === viewport) {
          if (targetRect.bottom > viewportHeight) {
            return false;
          }

          if (targetRect.left > viewportWidth) {
            return false;
          }
        }

        return true;
      });

      if (isVisible) {
        return [];
      }
    }

    var targetBlock;
    var targetInline;
    var computations = frames.map(function (frame) {
      var frameRect = frame.getBoundingClientRect();
      var frameStyle = getComputedStyle(frame);
      var borderLeft = parseInt(frameStyle.borderLeftWidth, 10);
      var borderTop = parseInt(frameStyle.borderTopWidth, 10);
      var borderRight = parseInt(frameStyle.borderRightWidth, 10);
      var borderBottom = parseInt(frameStyle.borderBottomWidth, 10);
      var blockScroll = 0;
      var inlineScroll = 0;

      if (block === 'start') {
        if (!targetBlock) {
          targetBlock = targetRect.top;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock;
        } else {
          var offset = Math.min(targetBlock - frameRect.top, frame.scrollHeight - frame.clientHeight - frame.scrollTop);
          blockScroll = frame.scrollTop + offset - borderTop;
        }
      }

      if (block === 'center') {
        if (!targetBlock) {
          targetBlock = targetRect.top + targetRect.height / 2;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock - viewportHeight / 2;
        } else {
          var _offset = 0 - Math.min(frameRect.top + frameRect.height / 2 - targetBlock, frame.scrollTop);

          blockScroll = frame.scrollTop + _offset;
        }
      }

      if (block === 'end') {
        if (!targetBlock) {
          targetBlock = targetRect.bottom;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock - viewportHeight;
        } else {
          var _offset2 = 0 - Math.min(frameRect.bottom - targetBlock, frame.scrollTop);

          blockScroll = frame.scrollTop + _offset2 + borderBottom;
        }
      }

      if (block === 'nearest') {
        if (!targetBlock) {
          targetBlock = targetRect.top;
        }

        if (viewport === frame) {
          var _offset3 = alignNearest(viewportY, viewportY + viewportHeight, viewportHeight, borderTop, borderBottom, viewportY + targetBlock, viewportY + targetBlock + targetRect.height, targetRect.height);

          blockScroll = viewportY + _offset3;
        } else {
          var _offset4 = alignNearest(frameRect.top, frameRect.bottom, frameRect.height, borderTop, borderBottom, targetBlock, targetBlock + targetRect.height, targetRect.height);

          blockScroll = frame.scrollTop + _offset4;
        }
      }

      if (inline === 'start') {
        if (!targetInline) {
          targetInline = targetRect.left;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline;
        } else {
          var _offset5 = Math.min(targetInline - frameRect.left, frame.scrollHeight - frame.clientLeft - frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset5 - borderLeft;
        }
      }

      if (inline === 'center') {
        if (!targetInline) {
          targetInline = targetRect.left + targetRect.width / 2;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline - viewportWidth / 2;
        } else {
          var _offset6 = 0 - Math.min(frameRect.left + frameRect.width / 2 - targetInline, frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset6;
        }
      }

      if (inline === 'end') {
        if (!targetInline) {
          targetInline = targetRect.right;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline - viewportWidth;
        } else {
          var _offset7 = 0 - Math.min(frameRect.right - targetInline, frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset7 + borderRight;
        }
      }

      if (inline === 'nearest') {
        if (!targetInline) {
          targetInline = targetRect.left;
        }

        if (viewport === frame) {
          var _offset8 = alignNearest(viewportX, viewportX + viewportWidth, viewportWidth, borderLeft, borderRight, viewportX + targetInline, viewportX + targetInline + targetRect.width, targetRect.width);

          inlineScroll = viewportX + _offset8;
        } else {
          var _offset9 = alignNearest(frameRect.left, frameRect.right, frameRect.width, borderLeft, borderRight, targetInline, targetInline + targetRect.width, targetRect.width);

          inlineScroll = frame.scrollLeft + _offset9;
        }
      }

      targetBlock += frame.scrollTop - blockScroll;
      targetInline += frame.scrollLeft - inlineScroll;
      return {
        el: frame,
        top: blockScroll,
        left: inlineScroll
      };
    });
    return computations;
  });

  var isFunction = function isFunction(arg) {
    return typeof arg === 'function';
  };

  var isOptionsObject = function isOptionsObject(options) {
    return options === Object(options) && Object.keys(options).length !== 0;
  };

  var defaultBehavior = function defaultBehavior(actions, behavior) {
    if (behavior === void 0) {
      behavior = 'auto';
    }

    var viewport = getViewport();
    var supportsScrollBehavior = 'scrollBehavior' in viewport.style;
    actions.forEach(function (_ref) {
      var el = _ref.el,
          top = _ref.top,
          left = _ref.left;

      if (el.scroll && supportsScrollBehavior) {
        el.scroll({
          top: top,
          left: left,
          behavior: behavior
        });
      } else {
        if (el === viewport) {
          window.scrollTo(left, top);
        } else {
          el.scrollTop = top;
          el.scrollLeft = left;
        }
      }
    });
  };

  var getOptions = function getOptions(options) {
    if (options === void 0) {
      options = true;
    }

    if (options === true || options === null) {
      return {
        block: 'start',
        inline: 'nearest'
      };
    } else if (options === false) {
      return {
        block: 'end',
        inline: 'nearest'
      };
    } else if (isOptionsObject(options)) {
      return options;
    }

    return {
      block: 'start',
      inline: 'nearest'
    };
  };

  function scrollIntoView(target, options) {
    if (options === void 0) {
      options = true;
    }

    if (isOptionsObject(options) && isFunction(options.behavior)) {
      return options.behavior(compute(target, options));
    }

    var computeOptions = getOptions(options);
    return defaultBehavior(compute(target, computeOptions), computeOptions.behavior);
  }

  var memoizedNow;

  var now = function now() {
    if (!memoizedNow) {
      memoizedNow = 'performance' in window ? performance.now.bind(performance) : Date.now;
    }

    return memoizedNow();
  };

  function step(context) {
    var time = now();
    var elapsed = Math.min((time - context.startTime) / context.duration, 1);
    var value = context.ease(elapsed);
    var currentX = context.startX + (context.x - context.startX) * value;
    var currentY = context.startY + (context.y - context.startY) * value;
    context.method(currentX, currentY);

    if (currentX !== context.x || currentY !== context.y) {
      requestAnimationFrame(function () {
        return step(context);
      });
    }
  }

  function smoothScroll(el, x, y, duration, ease, cb) {
    if (duration === void 0) {
      duration = 450;
    }

    if (ease === void 0) {
      ease = function ease(t) {
        return 1 + --t * t * t * t * t;
      };
    }

    var scrollable;
    var startX;
    var startY;
    var method;

    if (el === document.documentElement) {
      scrollable = window;
      startX = window.scrollX || window.pageXOffset;
      startY = window.scrollY || window.pageYOffset;

      method = function method(x, y) {
        return window.scroll(x, y);
      };
    } else {
      scrollable = el;
      startX = el.scrollLeft;
      startY = el.scrollTop;

      method = function method(x, y) {
        el.scrollLeft = x;
        el.scrollTop = y;
      };
    }

    step({
      scrollable: scrollable,
      method: method,
      startTime: now(),
      startX: startX,
      startY: startY,
      x: x,
      y: y,
      duration: duration,
      ease: ease,
      cb: cb
    });
  }

  var shouldSmoothScroll = function shouldSmoothScroll(options) {
    return options && !options.behavior || options.behavior === 'smooth';
  };

  function scroll(target, options) {
    if (shouldSmoothScroll(options)) {
      var overrides = options || {};
      return scrollIntoView(target, {
        block: overrides.block,
        inline: overrides.inline,
        scrollMode: overrides.scrollMode,
        boundary: overrides.boundary,
        behavior: function behavior(actions) {
          return Promise.all(actions.map(function (_ref) {
            var el = _ref.el,
                left = _ref.left,
                top = _ref.top;
            return new Promise(function (resolve) {
              return smoothScroll(el, left, top, overrides.duration, overrides.ease, function () {
                return resolve();
              });
            });
          }));
        }
      });
    }

    return scrollIntoView(target, options);
  }

  var smoothScrollIntoView = scroll;

  return smoothScrollIntoView;

})));

==> smooth-scroll-into-view-if-needed-1.1.6.tgz: package/umd/smooth-scroll-into-view-if-needed.js <==
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() :
  typeof define === 'function' && define.amd ? define(factory) :
  (global.scrollIntoView = factory());
}(this, (function () { 'use strict';

  var viewport;
  var getViewport = (function () {
    if (!viewport) {
      viewport = document.compatMode === 'CSS1Compat' ? document.documentElement : document.scrollingElement || document.documentElement;
    }

    return viewport;
  });

  var isElement = function isElement(el) {
    return el != null && typeof el === 'object' && (el.nodeType === 1 || el.nodeType === 11);
  };

  var hasScrollableSpace = function hasScrollableSpace(el, axis) {
    return axis === 'X' ? el.clientWidth < el.scrollWidth : el.clientHeight < el.scrollHeight;
  };

  var canOverflow = function canOverflow(el, axis, skipOverflowHiddenElements) {
    var overflowValue = getComputedStyle(el, null)['overflow' + axis];

    if (skipOverflowHiddenElements && overflowValue === 'hidden') {
      return false;
    }

    return overflowValue !== 'visible' && overflowValue !== 'clip';
  };

  var isScrollable = function isScrollable(el, skipOverflowHiddenElements) {
    return el === getViewport() || hasScrollableSpace(el, 'Y') && canOverflow(el, 'Y', skipOverflowHiddenElements) || hasScrollableSpace(el, 'X') && canOverflow(el, 'X', skipOverflowHiddenElements);
  };

  var alignNearest = function alignNearest(scrollingEdgeStart, scrollingEdgeEnd, scrollingSize, scrollingBorderStart, scrollingBorderEnd, elementEdgeStart, elementEdgeEnd, elementSize) {
    if (elementEdgeStart < scrollingEdgeStart && elementEdgeEnd > scrollingEdgeEnd || elementEdgeStart > scrollingEdgeStart && elementEdgeEnd < scrollingEdgeEnd) {
      return 0;
    }

    if (elementEdgeStart < scrollingEdgeStart && elementSize < scrollingSize || elementEdgeEnd > scrollingEdgeEnd && elementSize > scrollingSize) {
      return elementEdgeStart - scrollingEdgeStart - scrollingBorderStart;
    }

    if (elementEdgeEnd > scrollingEdgeEnd && elementSize < scrollingSize || elementEdgeStart < scrollingEdgeStart && elementSize > scrollingSize) {
      return elementEdgeEnd - scrollingEdgeEnd + scrollingBorderEnd;
    }

    return 0;
  };

  var compute = (function (target, options) {
    if (options === void 0) {
      options = {};
    }

    var _options = options,
        _options$scrollMode = _options.scrollMode,
        scrollMode = _options$scrollMode === void 0 ? 'always' : _options$scrollMode,
        _options$block = _options.block,
        block = _options$block === void 0 ? 'center' : _options$block,
        _options$inline = _options.inline,
        inline = _options$inline === void 0 ? 'nearest' : _options$inline,
        boundary = _options.boundary,
        _options$skipOverflow = _options.skipOverflowHiddenElements,
        skipOverflowHiddenElements = _options$skipOverflow === void 0 ? false : _options$skipOverflow;
    var checkBoundary = typeof boundary === 'function' ? boundary : function (node) {
      return node !== boundary;
    };

    if (!isElement(target)) {
      throw new Error('Element is required in scrollIntoView');
    }

    var targetRect = target.getBoundingClientRect();
    var frames = [];
    var parent;

    while (isElement(parent = target.parentNode || target.host) && checkBoundary(target)) {
      if (isScrollable(parent, skipOverflowHiddenElements)) {
        frames.push(parent);
      }

      target = parent;
    }

    var viewport = getViewport();
    var viewportWidth = window.visualViewport ? window.visualViewport.width : Math.min(viewport.clientWidth, window.innerWidth);
    var viewportHeight = window.visualViewport ? window.visualViewport.height : Math.min(viewport.clientHeight, window.innerHeight);
    var viewportX = window.scrollX || window.pageXOffset;
    var viewportY = window.scrollY || window.pageYOffset;

    if (scrollMode === 'if-needed') {
      var isVisible = frames.every(function (frame) {
        var frameRect = frame.getBoundingClientRect();

        if (targetRect.top < frameRect.top) {
          return false;
        }

        if (targetRect.bottom > frameRect.bottom) {
          return false;
        }

        if (frame === viewport) {
          if (targetRect.bottom > viewportHeight || targetRect.top < 0) {
            return false;
          }

          if (targetRect.left > viewportWidth || targetRect.right < 0) {
            return false;
          }
        }

        return true;
      });

      if (isVisible) {
        return [];
      }
    }

    var targetBlock;
    var targetInline;
    var computations = frames.map(function (frame) {
      var frameRect = frame.getBoundingClientRect();
      var frameStyle = getComputedStyle(frame);
      var borderLeft = parseInt(frameStyle.borderLeftWidth, 10);
      var borderTop = parseInt(frameStyle.borderTopWidth, 10);
      var borderRight = parseInt(frameStyle.borderRightWidth, 10);
      var borderBottom = parseInt(frameStyle.borderBottomWidth, 10);
      var blockScroll = 0;
      var inlineScroll = 0;

      if (block === 'start') {
        if (!targetBlock) {
          targetBlock = targetRect.top;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock;
        } else {
          var offset = Math.min(targetBlock - frameRect.top, frame.scrollHeight - frame.clientHeight - frame.scrollTop);
          blockScroll = frame.scrollTop + offset - borderTop;
        }
      }

      if (block === 'center') {
        if (!targetBlock) {
          targetBlock = targetRect.top + targetRect.height / 2;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock - viewportHeight / 2;
        } else {
          var _offset = 0 - Math.min(frameRect.top + frameRect.height / 2 - targetBlock, frame.scrollTop);

          blockScroll = frame.scrollTop + _offset;
        }
      }

      if (block === 'end') {
        if (!targetBlock) {
          targetBlock = targetRect.bottom;
        }

        if (viewport === frame) {
          blockScroll = viewportY + targetBlock - viewportHeight;
        } else {
          var _offset2 = 0 - Math.min(frameRect.bottom - targetBlock, frame.scrollTop);

          blockScroll = frame.scrollTop + _offset2 + borderBottom;
        }
      }

      if (block === 'nearest') {
        if (!targetBlock) {
          targetBlock = targetRect.top;
        }

        if (viewport === frame) {
          var _offset3 = alignNearest(viewportY, viewportY + viewportHeight, viewportHeight, borderTop, borderBottom, viewportY + targetBlock, viewportY + targetBlock + targetRect.height, targetRect.height);

          blockScroll = viewportY + _offset3;
        } else {
          var _offset4 = alignNearest(frameRect.top, frameRect.bottom, frameRect.height, borderTop, borderBottom, targetBlock, targetBlock + targetRect.height, targetRect.height);

          blockScroll = frame.scrollTop + _offset4;
        }
      }

      if (inline === 'start') {
        if (!targetInline) {
          targetInline = targetRect.left;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline;
        } else {
          var _offset5 = Math.min(targetInline - frameRect.left, frame.scrollHeight - frame.clientLeft - frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset5 - borderLeft;
        }
      }

      if (inline === 'center') {
        if (!targetInline) {
          targetInline = targetRect.left + targetRect.width / 2;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline - viewportWidth / 2;
        } else {
          var _offset6 = 0 - Math.min(frameRect.left + frameRect.width / 2 - targetInline, frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset6;
        }
      }

      if (inline === 'end') {
        if (!targetInline) {
          targetInline = targetRect.right;
        }

        if (viewport === frame) {
          inlineScroll = viewportX + targetInline - viewportWidth;
        } else {
          var _offset7 = 0 - Math.min(frameRect.right - targetInline, frame.scrollLeft);

          inlineScroll = frame.scrollLeft + _offset7 + borderRight;
        }
      }

      if (inline === 'nearest') {
        if (!targetInline) {
          targetInline = targetRect.left;
        }

        if (viewport === frame) {
          var _offset8 = alignNearest(viewportX, viewportX + viewportWidth, viewportWidth, borderLeft, borderRight, viewportX + targetInline, viewportX + targetInline + targetRect.width, targetRect.width);

          inlineScroll = viewportX + _offset8;
        } else {
          var _offset9 = alignNearest(frameRect.left, frameRect.right, frameRect.width, borderLeft, borderRight, targetInline, targetInline + targetRect.width, targetRect.width);

          inlineScroll = frame.scrollLeft + _offset9;
        }
      }

      targetBlock += frame.scrollTop - blockScroll;
      targetInline += frame.scrollLeft - inlineScroll;
      return {
        el: frame,
        top: blockScroll,
        left: inlineScroll
      };
    });
    return computations;
  });

  var isFunction = function isFunction(arg) {
    return typeof arg === 'function';
  };

  var isOptionsObject = function isOptionsObject(options) {
    return options === Object(options) && Object.keys(options).length !== 0;
  };

  var defaultBehavior = function defaultBehavior(actions, behavior) {
    if (behavior === void 0) {
      behavior = 'auto';
    }

    var viewport = getViewport();
    var supportsScrollBehavior = 'scrollBehavior' in viewport.style;
    actions.forEach(function (_ref) {
      var el = _ref.el,
          top = _ref.top,
          left = _ref.left;

      if (el.scroll && supportsScrollBehavior) {
        el.scroll({
          top: top,
          left: left,
          behavior: behavior
        });
      } else {
        if (el === viewport) {
          window.scrollTo(left, top);
        } else {
          el.scrollTop = top;
          el.scrollLeft = left;
        }
      }
    });
  };

  var getOptions = function getOptions(options) {
    if (options === void 0) {
      options = true;
    }

    if (options === true || options === null) {
      return {
        block: 'start',
        inline: 'nearest'
      };
    } else if (options === false) {
      return {
        block: 'end',
        inline: 'nearest'
      };
    } else if (isOptionsObject(options)) {
      return options;
    }

    return {
      block: 'start',
      inline: 'nearest'
    };
  };

  function scrollIntoView(target, options) {
    if (options === void 0) {
      options = true;
    }

    if (isOptionsObject(options) && isFunction(options.behavior)) {
      return options.behavior(compute(target, options));
    }

    var computeOptions = getOptions(options);
    return defaultBehavior(compute(target, computeOptions), computeOptions.behavior);
  }

  var memoizedNow;

  var now = function now() {
    if (!memoizedNow) {
      memoizedNow = 'performance' in window ? performance.now.bind(performance) : Date.now;
    }

    return memoizedNow();
  };

  function step(context) {
    var time = now();
    var elapsed = Math.min((time - context.startTime) / context.duration, 1);
    var value = context.ease(elapsed);
    var currentX = context.startX + (context.x - context.startX) * value;
    var currentY = context.startY + (context.y - context.startY) * value;
    context.method(currentX, currentY);

    if (currentX !== context.x || currentY !== context.y) {
      requestAnimationFrame(function () {
        return step(context);
      });
    }
  }

  function smoothScroll(el, x, y, duration, ease, cb) {
    if (duration === void 0) {
      duration = 450;
    }

    if (ease === void 0) {
      ease = function ease(t) {
        return 1 + --t * t * t * t * t;
      };
    }

    var scrollable;
    var startX;
    var startY;
    var method;

    if (el === document.documentElement) {
      scrollable = window;
      startX = window.scrollX || window.pageXOffset;
      startY = window.scrollY || window.pageYOffset;

      method = function method(x, y) {
        return window.scroll(x, y);
      };
    } else {
      scrollable = el;
      startX = el.scrollLeft;
      startY = el.scrollTop;

      method = function method(x, y) {
        el.scrollLeft = x;
        el.scrollTop = y;
      };
    }

    step({
      scrollable: scrollable,
      method: method,
      startTime: now(),
      startX: startX,
      startY: startY,
      x: x,
      y: y,
      duration: duration,
      ease: ease,
      cb: cb
    });
  }

  var shouldSmoothScroll = function shouldSmoothScroll(options) {
    return options && !options.behavior || options.behavior === 'smooth';
  };

  function scroll(target, options) {
    if (shouldSmoothScroll(options)) {
      var overrides = options || {};
      return scrollIntoView(target, {
        block: overrides.block,
        inline: overrides.inline,
        scrollMode: overrides.scrollMode,
        boundary: overrides.boundary,
        behavior: function behavior(actions) {
          return Promise.all(actions.map(function (_ref) {
            var el = _ref.el,
                left = _ref.left,
                top = _ref.top;
            return new Promise(function (resolve) {
              return smoothScroll(el, left, top, overrides.duration, overrides.ease, function () {
                return resolve();
              });
            });
          }));
        }
      });
    }

    return scrollIntoView(target, options);
  }

  var smoothScrollIntoView = scroll;

  return smoothScrollIntoView;

})));
